@@ -20,7 +20,10 @@ class ValidationManager(models.Manager):
 		v = Validation(user=user)
 
 		salt = hashlib.sha256(str(random.random())).hexdigest()
-		key = hashlib.sha256(salt + user.get_full_name()).hexdigest()
+		# we encode it to utf-8 and ignore any stray input to be able to
+		# hash the string
+		to_hash = (salt + user.get_full_name()).encode('utf-8', 'ignore')
+		key = hashlib.sha256(to_hash).hexdigest()
 
 		v.key = key
 		v.save(using=self._db)
